@@ -76,6 +76,11 @@ int cmCPackDebGenerator::PackageOnePack(std::string initialTopLevel,
       packageFileName.c_str());
   // Tell CPackDeb.cmake the name of the component GROUP.
   this->SetOption("CPACK_DEB_PACKAGE_COMPONENT",packageName.c_str());
+  // Tell CPackDeb.cmake the path where the component is.
+  std::string component_path = "/";
+  component_path += packageName;
+  this->SetOption("CPACK_DEB_PACKAGE_COMPONENT_PART_PATH",
+                  component_path.c_str());
   if (!this->ReadListFile("CPackDeb.cmake"))
     {
     cmCPackLogger(cmCPackLog::LOG_ERROR,
@@ -198,8 +203,11 @@ int cmCPackDebGenerator::PackageComponentsAllInOne()
   /* replace the TEMPORARY package file name */
   this->SetOption("CPACK_TEMPORARY_PACKAGE_FILE_NAME",
       packageFileName.c_str());
-  // Tell CPackDeb.cmake the name of the component GROUP.
-  this->SetOption("CPACK_DEB_PACKAGE_COMPONENT",compInstDirName.c_str());
+  // Tell CPackDeb.cmake the path where the component is.
+  std::string component_path = "/";
+  component_path += compInstDirName;
+  this->SetOption("CPACK_DEB_PACKAGE_COMPONENT_PART_PATH",
+                  component_path.c_str());
   if (!this->ReadListFile("CPackDeb.cmake"))
     {
     cmCPackLogger(cmCPackLog::LOG_ERROR,
@@ -236,7 +244,7 @@ int cmCPackDebGenerator::PackageFiles()
   int retval = -1;
 
   /* Are we in the component packaging case */
-  if (SupportsComponentInstallation()) {
+  if (WantsComponentInstallation()) {
     // CASE 1 : COMPONENT ALL-IN-ONE package
     // If ALL GROUPS or ALL COMPONENTS in ONE package has been requested
     // then the package file is unique and should be open here.
@@ -293,15 +301,15 @@ int cmCPackDebGenerator::createDeb()
 
   // debian policy enforce lower case for package name
   // mandatory entries:
-  std::string debian_pkg_name = cmsys::SystemTools::LowerCase( 
+  std::string debian_pkg_name = cmsys::SystemTools::LowerCase(
                                 this->GetOption("CPACK_DEBIAN_PACKAGE_NAME") );
-  const char* debian_pkg_version = 
+  const char* debian_pkg_version =
                                this->GetOption("CPACK_DEBIAN_PACKAGE_VERSION");
-  const char* debian_pkg_section = 
+  const char* debian_pkg_section =
                                this->GetOption("CPACK_DEBIAN_PACKAGE_SECTION");
-  const char* debian_pkg_priority = 
+  const char* debian_pkg_priority =
                               this->GetOption("CPACK_DEBIAN_PACKAGE_PRIORITY");
-  const char* debian_pkg_arch = 
+  const char* debian_pkg_arch =
                           this->GetOption("CPACK_DEBIAN_PACKAGE_ARCHITECTURE");
   const char* maintainer =  this->GetOption("CPACK_DEBIAN_PACKAGE_MAINTAINER");
   const char* desc =       this->GetOption("CPACK_DEBIAN_PACKAGE_DESCRIPTION");
@@ -480,11 +488,16 @@ int cmCPackDebGenerator::createDeb()
     // Do not end the md5sum file with yet another (invalid)
     }
 
-  cmd = "\"";
-  cmd += cmakeExecutable;
-  cmd += "\" -E tar cfz control.tar.gz ./control ./md5sums";
-  const char* controlExtra =
-    this->GetOption("CPACK_DEBIAN_PACKAGE_CONTROL_EXTRA");
+    cmd = "";
+    if (NULL != this->GetOption("CPACK_DEBIAN_FAKEROOT_EXECUTABLE"))
+      {
+      cmd = this->GetOption("CPACK_DEBIAN_FAKEROOT_EXECUTABLE");
+      }
+    cmd += " \"";
+    cmd += cmakeExecutable;
+    cmd += "\" -E tar cfz control.tar.gz ./control ./md5sums";
+    const char* controlExtra =
+      this->GetOption("CPACK_DEBIAN_PACKAGE_CONTROL_EXTRA");
   if( controlExtra )
     {
     std::vector<std::string> controlExtraList;
@@ -714,8 +727,8 @@ static int copy_ar(CF *cfp, off_t size)
 
   FILE* from = cfp->rFile;
   FILE* to = cfp->wFile;
-  while (sz && 
-        (nr = fread(buf, 1, sz < static_cast<off_t>(sizeof(buf)) 
+  while (sz &&
+        (nr = fread(buf, 1, sz < static_cast<off_t>(sizeof(buf))
                     ? static_cast<size_t>(sz) : sizeof(buf), from ))
                > 0) {
     sz -= nr;
@@ -726,7 +739,7 @@ static int copy_ar(CF *cfp, off_t size)
   if (sz)
     return -2;
 
-  if (cfp->flags & WPAD && (size + ar_already_written) & 1 
+  if (cfp->flags & WPAD && (size + ar_already_written) & 1
       && fwrite(&pad, 1, 1, to) != 1)
     return -4;
 
@@ -758,13 +771,13 @@ static int put_arobj(CF *cfp, struct stat *sb)
     }
   if (lname > sizeof(hdr->ar_name) || strchr(name, ' '))
     (void)sprintf(ar_hb, HDR1, AR_EFMT1, (int)lname,
-                  (long int)sb->st_mtime, uid, gid, sb->st_mode,
-                  (long long)sb->st_size + lname, ARFMAG);
+                  (long int)sb->st_mtime, (unsigned)uid, (unsigned)gid,
+                  sb->st_mode, (long long)sb->st_size + lname, ARFMAG);
     else {
       lname = 0;
-      (void)sprintf(ar_hb, HDR2, name, 
-                    (long int)sb->st_mtime, uid, gid, sb->st_mode, 
-                    (long long)sb->st_size, ARFMAG);
+      (void)sprintf(ar_hb, HDR2, name,
+                    (long int)sb->st_mtime, (unsigned)uid, (unsigned)gid,
+                    sb->st_mode, (long long)sb->st_size, ARFMAG);
       }
     off_t size = sb->st_size;
 
@@ -785,7 +798,7 @@ static int put_arobj(CF *cfp, struct stat *sb)
 
 /* append --
  *      Append files to the archive - modifies original archive or creates
- *      a new archive if named archive does not exist. 
+ *      a new archive if named archive does not exist.
  */
 static int ar_append(const char* archive,const std::vector<std::string>& files)
 {
