@@ -1,19 +1,14 @@
-/*=========================================================================
+/*============================================================================
+  CMake - Cross Platform Makefile Generator
+  Copyright 2000-2009 Kitware, Inc., Insight Software Consortium
 
-  Program:   CMake - Cross-Platform Makefile Generator
-  Module:    $RCSfile: cmCPackPackageMakerGenerator.cxx,v $
-  Language:  C++
-  Date:      $Date: 2008-10-24 15:18:55 $
-  Version:   $Revision: 1.23.2.4 $
+  Distributed under the OSI-approved BSD License (the "License");
+  see accompanying file Copyright.txt for details.
 
-  Copyright (c) 2002 Kitware, Inc., Insight Consortium.  All rights reserved.
-  See Copyright.txt or http://www.cmake.org/HTML/Copyright.html for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
+  This software is distributed WITHOUT ANY WARRANTY; without even the
+  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+  See the License for more information.
+============================================================================*/
 #include "cmCPackPackageMakerGenerator.h"
 
 #include "cmake.h"
@@ -57,19 +52,17 @@ int cmCPackPackageMakerGenerator::CopyInstallScript(const char* resdir,
   cmSystemTools::CopyFileAlways(script, dst.c_str());
   cmSystemTools::SetPermissions(dst.c_str(),0777);
   cmCPackLogger(cmCPackLog::LOG_VERBOSE,
-                "copy script : " << script << "\ninto " << dst.c_str() << 
+                "copy script : " << script << "\ninto " << dst.c_str() <<
                 std::endl);
 
   return 1;
 }
 
 //----------------------------------------------------------------------
-int cmCPackPackageMakerGenerator::CompressFiles(const char* outFileName,
-  const char* toplevel,
-  const std::vector<std::string>& files)
+int cmCPackPackageMakerGenerator::PackageFiles()
 {
-  (void) files; // TODO: Fix api to not need files.
-  (void) toplevel; // TODO: Use toplevel
+  // TODO: Use toplevel
+  //       It is used! Is this an obsolete comment?
 
   std::string resDir; // Where this package's resources will go.
   std::string packageDirFileName
@@ -86,7 +79,7 @@ int cmCPackPackageMakerGenerator::CompressFiles(const char* outFileName,
     if ( !cmsys::SystemTools::MakeDirectory(packageDirFileName.c_str()))
       {
       cmCPackLogger(cmCPackLog::LOG_ERROR,
-                    "unable to create package directory " 
+                    "unable to create package directory "
                     << packageDirFileName << std::endl);
         return 0;
       }
@@ -96,7 +89,7 @@ int cmCPackPackageMakerGenerator::CompressFiles(const char* outFileName,
     if ( !cmsys::SystemTools::MakeDirectory(resDir.c_str()))
       {
       cmCPackLogger(cmCPackLog::LOG_ERROR,
-                    "unable to create package subdirectory " << resDir 
+                    "unable to create package subdirectory " << resDir
                     << std::endl);
         return 0;
       }
@@ -105,7 +98,7 @@ int cmCPackPackageMakerGenerator::CompressFiles(const char* outFileName,
     if ( !cmsys::SystemTools::MakeDirectory(resDir.c_str()))
       {
       cmCPackLogger(cmCPackLog::LOG_ERROR,
-                    "unable to create package subdirectory " << resDir 
+                    "unable to create package subdirectory " << resDir
                     << std::endl);
         return 0;
       }
@@ -113,56 +106,101 @@ int cmCPackPackageMakerGenerator::CompressFiles(const char* outFileName,
     resDir += "/en.lproj";
     }
 
-
-  // Create directory structure
-  std::string preflightDirName = resDir + "/PreFlight";
-  std::string postflightDirName = resDir + "/PostFlight";
   const char* preflight = this->GetOption("CPACK_PREFLIGHT_SCRIPT");
   const char* postflight = this->GetOption("CPACK_POSTFLIGHT_SCRIPT");
   const char* postupgrade = this->GetOption("CPACK_POSTUPGRADE_SCRIPT");
-  // if preflight or postflight scripts not there create directories
-  // of the same name, I think this makes it work
-  if(!preflight)
+
+  if(this->Components.empty())
     {
-    if ( !cmsys::SystemTools::MakeDirectory(preflightDirName.c_str()))
+    // Create directory structure
+    std::string preflightDirName = resDir + "/PreFlight";
+    std::string postflightDirName = resDir + "/PostFlight";
+    // if preflight or postflight scripts not there create directories
+    // of the same name, I think this makes it work
+    if(!preflight)
       {
-      cmCPackLogger(cmCPackLog::LOG_ERROR,
-                    "Problem creating installer directory: "
-                    << preflightDirName.c_str() << std::endl);
-      return 0;
+      if ( !cmsys::SystemTools::MakeDirectory(preflightDirName.c_str()))
+        {
+        cmCPackLogger(cmCPackLog::LOG_ERROR,
+                      "Problem creating installer directory: "
+                      << preflightDirName.c_str() << std::endl);
+        return 0;
+        }
+      }
+    if(!postflight)
+      {
+      if ( !cmsys::SystemTools::MakeDirectory(postflightDirName.c_str()))
+        {
+        cmCPackLogger(cmCPackLog::LOG_ERROR,
+                      "Problem creating installer directory: "
+                      << postflightDirName.c_str() << std::endl);
+        return 0;
+        }
+      }
+    // if preflight, postflight, or postupgrade are set
+    // then copy them into the resource directory and make
+    // them executable
+    if(preflight)
+      {
+      this->CopyInstallScript(resDir.c_str(),
+                              preflight,
+                              "preflight");
+      }
+    if(postflight)
+      {
+      this->CopyInstallScript(resDir.c_str(),
+                              postflight,
+                              "postflight");
+      }
+    if(postupgrade)
+      {
+      this->CopyInstallScript(resDir.c_str(),
+                              postupgrade,
+                              "postupgrade");
       }
     }
-  if(!postflight)
+  else if(postflight)
     {
-    if ( !cmsys::SystemTools::MakeDirectory(postflightDirName.c_str()))
+    // create a postflight component to house the script
+    this->PostFlightComponent.Name = "PostFlight";
+    this->PostFlightComponent.DisplayName = "PostFlight";
+    this->PostFlightComponent.Description = "PostFlight";
+    this->PostFlightComponent.IsHidden = true;
+
+    // empty directory for pkg contents
+    std::string packageDir = toplevel + "/" + PostFlightComponent.Name;
+    if (!cmsys::SystemTools::MakeDirectory(packageDir.c_str()))
       {
       cmCPackLogger(cmCPackLog::LOG_ERROR,
-                    "Problem creating installer directory: "
-                    << postflightDirName.c_str() << std::endl);
+                    "Problem creating component packages directory: "
+                    << packageDir.c_str() << std::endl);
       return 0;
       }
-    }
-  // if preflight, postflight, or postupgrade are set 
-  // then copy them into the resource directory and make
-  // them executable
-  if(preflight)
-    {
-    this->CopyInstallScript(resDir.c_str(),
-                            preflight,
-                            "preflight");
-    }
-  if(postflight)
-    {
-    this->CopyInstallScript(resDir.c_str(),
+
+    // create package
+    std::string packageFileDir = packageDirFileName + "/Contents/Packages/";
+    if (!cmsys::SystemTools::MakeDirectory(packageFileDir.c_str()))
+      {
+      cmCPackLogger(cmCPackLog::LOG_ERROR,
+                   "Problem creating component PostFlight Packages directory: "
+                    << packageFileDir.c_str() << std::endl);
+      return 0;
+      }
+    std::string packageFile = packageFileDir +
+      this->GetPackageName(PostFlightComponent);
+    if (!this->GenerateComponentPackage(packageFile.c_str(),
+                                        packageDir.c_str(),
+                                        PostFlightComponent))
+      {
+      return 0;
+      }
+
+    // copy postflight script into resource directory of .pkg
+    std::string resourceDir = packageFile + "/Contents/Resources";
+    this->CopyInstallScript(resourceDir.c_str(),
                             postflight,
                             "postflight");
     }
-  if(postupgrade)
-    {
-    this->CopyInstallScript(resDir.c_str(),
-                            postupgrade,
-                            "postupgrade");
-    }
 
   if (!this->Components.empty())
     {
@@ -213,7 +251,7 @@ int cmCPackPackageMakerGenerator::CompressFiles(const char* outFileName,
             if (!cmSystemTools::MakeDirectory(uploadDirectory.c_str()))
               {
               cmCPackLogger(cmCPackLog::LOG_ERROR,
-                            "Unable to create package upload directory " 
+                            "Unable to create package upload directory "
                             << uploadDirectory << std::endl);
               return 0;
               }
@@ -261,7 +299,7 @@ int cmCPackPackageMakerGenerator::CompressFiles(const char* outFileName,
       std::string packageDir = toplevel;
       packageDir += '/';
       packageDir += compIt->first;
-      if (!this->GenerateComponentPackage(packageFile.c_str(), 
+      if (!this->GenerateComponentPackage(packageFile.c_str(),
                                           packageDir.c_str(),
                                           compIt->second))
         {
@@ -300,7 +338,7 @@ int cmCPackPackageMakerGenerator::CompressFiles(const char* outFileName,
       }
     pkgCmd << "\" -r \"" << this->GetOption("CPACK_TOPLEVEL_DIRECTORY")
            << "/Resources\" -i \""
-           << this->GetOption("CPACK_TOPLEVEL_DIRECTORY") 
+           << this->GetOption("CPACK_TOPLEVEL_DIRECTORY")
            << "/Info.plist\" -d \""
            << this->GetOption("CPACK_TOPLEVEL_DIRECTORY")
            << "/Description.plist\"";
@@ -323,11 +361,24 @@ int cmCPackPackageMakerGenerator::CompressFiles(const char* outFileName,
   cmOStringStream dmgCmd;
   dmgCmd << "\"" << this->GetOption("CPACK_INSTALLER_PROGRAM_DISK_IMAGE")
     << "\" create -ov -format UDZO -srcfolder \"" << packageDirFileName
-    << "\" \"" << outFileName << "\"";
+    << "\" \"" << packageFileNames[0] << "\"";
   std::string output;
   int retVal = 1;
-  bool res = cmSystemTools::RunSingleCommand(dmgCmd.str().c_str(), &output,
-    &retVal, 0, this->GeneratorVerbose, 0);
+  int numTries = 10;
+  bool res = false;
+  while(numTries > 0)
+    {
+    res = cmSystemTools::RunSingleCommand(dmgCmd.str().c_str(), &output,
+                                          &retVal, 0, this->GeneratorVerbose,
+                                          0);
+    if ( res && !retVal )
+      {
+      numTries = -1;
+      break;
+      }
+    cmSystemTools::Delay(500);
+    numTries--;
+    }
   if ( !res || retVal )
     {
     cmGeneratedFileStream ofs(tmpFile.c_str());
@@ -349,24 +400,73 @@ int cmCPackPackageMakerGenerator::InitializeInternal()
   cmCPackLogger(cmCPackLog::LOG_DEBUG,
     "cmCPackPackageMakerGenerator::Initialize()" << std::endl);
   this->SetOptionIfNotSet("CPACK_PACKAGING_INSTALL_PREFIX", "/usr");
-  std::vector<std::string> path;
-  std::string pkgPath
-    = "/Developer/Applications/Utilities/PackageMaker.app/Contents";
-  std::string versionFile = pkgPath + "/version.plist";
-  if ( !cmSystemTools::FileExists(versionFile.c_str()) )
+
+  // Starting with Xcode 4.3, PackageMaker is a separate app, and you
+  // can put it anywhere you want. So... use a variable for its location.
+  // People who put it in unexpected places can use the variable to tell
+  // us where it is.
+  //
+  // Use the following locations, in "most recent installation" order,
+  // to search for the PackageMaker app. Assume people who copy it into
+  // the new Xcode 4.3 app in "/Applications" will copy it into the nested
+  // Applications folder inside the Xcode bundle itself. Or directly in
+  // the "/Applications" directory.
+  //
+  // If found, save result in the CPACK_INSTALLER_PROGRAM variable.
+
+  std::vector<std::string> paths;
+  paths.push_back(
+    "/Applications/Xcode.app/Contents/Applications"
+    "/PackageMaker.app/Contents/MacOS");
+  paths.push_back(
+    "/Applications/Utilities"
+    "/PackageMaker.app/Contents/MacOS");
+  paths.push_back(
+    "/Applications"
+    "/PackageMaker.app/Contents/MacOS");
+  paths.push_back(
+    "/Developer/Applications/Utilities"
+    "/PackageMaker.app/Contents/MacOS");
+  paths.push_back(
+    "/Developer/Applications"
+    "/PackageMaker.app/Contents/MacOS");
+
+  std::string pkgPath;
+  const char *inst_program = this->GetOption("CPACK_INSTALLER_PROGRAM");
+  if (inst_program && *inst_program)
     {
-    pkgPath = "/Developer/Applications/PackageMaker.app/Contents";
-    std::string newVersionFile = pkgPath + "/version.plist";
-    if ( !cmSystemTools::FileExists(newVersionFile.c_str()) )
+    pkgPath = inst_program;
+    }
+  else
+    {
+    pkgPath = cmSystemTools::FindProgram("PackageMaker", paths, false);
+    if ( pkgPath.empty() )
       {
-      cmCPackLogger(cmCPackLog::LOG_ERROR,
-        "Cannot find PackageMaker compiler version file: "
-        << versionFile.c_str() << " or " << newVersionFile.c_str()
+      cmCPackLogger(cmCPackLog::LOG_ERROR, "Cannot find PackageMaker compiler"
         << std::endl);
       return 0;
       }
-    versionFile = newVersionFile;
+    this->SetOptionIfNotSet("CPACK_INSTALLER_PROGRAM", pkgPath.c_str());
     }
+
+  // Get path to the real PackageMaker, not a symlink:
+  pkgPath = cmSystemTools::GetRealPath(pkgPath.c_str());
+  // Up from there to find the version.plist file in the "Contents" dir:
+  std::string contents_dir;
+  contents_dir = cmSystemTools::GetFilenamePath(pkgPath);
+  contents_dir = cmSystemTools::GetFilenamePath(contents_dir);
+
+  std::string versionFile = contents_dir + "/version.plist";
+
+  if ( !cmSystemTools::FileExists(versionFile.c_str()) )
+    {
+    cmCPackLogger(cmCPackLog::LOG_ERROR,
+      "Cannot find PackageMaker compiler version file: "
+      << versionFile.c_str()
+      << std::endl);
+    return 0;
+    }
+
   std::ifstream ifs(versionFile.c_str());
   if ( !ifs )
     {
@@ -374,6 +474,7 @@ int cmCPackPackageMakerGenerator::InitializeInternal()
       "Cannot open PackageMaker compiler version file" << std::endl);
     return 0;
     }
+
   // Check the PackageMaker version
   cmsys::RegularExpression rexKey("<key>CFBundleShortVersionString</key>");
   cmsys::RegularExpression rexVersion("<string>([0-9]+.[0-9.]+)</string>");
@@ -418,7 +519,7 @@ int cmCPackPackageMakerGenerator::InitializeInternal()
   const char *packageCompat = this->GetOption("CPACK_OSX_PACKAGE_VERSION");
   if (packageCompat && *packageCompat)
     {
-    this->PackageCompatibilityVersion = atof(packageCompat);  
+    this->PackageCompatibilityVersion = atof(packageCompat);
     }
   else if (this->GetOption("CPACK_DOWNLOAD_SITE"))
     {
@@ -436,24 +537,15 @@ int cmCPackPackageMakerGenerator::InitializeInternal()
     this->PackageCompatibilityVersion = 10.3;
     }
 
-  pkgPath += "/MacOS";
-  path.push_back(pkgPath);
-  pkgPath = cmSystemTools::FindProgram("PackageMaker", path, false);
-  if ( pkgPath.empty() )
-    {
-    cmCPackLogger(cmCPackLog::LOG_ERROR, "Cannot find PackageMaker compiler"
-      << std::endl);
-    return 0;
-    }
-  this->SetOptionIfNotSet("CPACK_INSTALLER_PROGRAM", pkgPath.c_str());
-  pkgPath = cmSystemTools::FindProgram("hdiutil", path, false);
+  std::vector<std::string> no_paths;
+  pkgPath = cmSystemTools::FindProgram("hdiutil", no_paths, false);
   if ( pkgPath.empty() )
     {
     cmCPackLogger(cmCPackLog::LOG_ERROR, "Cannot find hdiutil compiler"
       << std::endl);
     return 0;
     }
-  this->SetOptionIfNotSet("CPACK_INSTALLER_PROGRAM_DISK_IMAGE", 
+  this->SetOptionIfNotSet("CPACK_INSTALLER_PROGRAM_DISK_IMAGE",
                           pkgPath.c_str());
 
   return this->Superclass::InitializeInternal();
@@ -469,7 +561,7 @@ bool cmCPackPackageMakerGenerator::CopyCreateResourceFile(const char* name,
   if ( !inFileName )
     {
     cmCPackLogger(cmCPackLog::LOG_ERROR, "CPack option: " << cpackVar.c_str()
-                  << " not specified. It should point to " 
+                  << " not specified. It should point to "
                   << (name ? name : "(NULL)")
                   << ".rtf, " << name
                   << ".html, or " << name << ".txt file" << std::endl);
@@ -477,7 +569,7 @@ bool cmCPackPackageMakerGenerator::CopyCreateResourceFile(const char* name,
     }
   if ( !cmSystemTools::FileExists(inFileName) )
     {
-    cmCPackLogger(cmCPackLog::LOG_ERROR, "Cannot find " 
+    cmCPackLogger(cmCPackLog::LOG_ERROR, "Cannot find "
                   << (name ? name : "(NULL)")
                   << " resource file: " << inFileName << std::endl);
     return false;
@@ -500,7 +592,7 @@ bool cmCPackPackageMakerGenerator::CopyCreateResourceFile(const char* name,
   this->SetOption(("CPACK_RESOURCE_FILE_" + uname + "_NOPATH").c_str(),
                   (name + ext).c_str());
 
-  cmCPackLogger(cmCPackLog::LOG_VERBOSE, "Configure file: " 
+  cmCPackLogger(cmCPackLog::LOG_VERBOSE, "Configure file: "
                 << (inFileName ? inFileName : "(NULL)")
                 << " to " << destFileName.c_str() << std::endl);
   this->ConfigureFile(inFileName, destFileName.c_str());
@@ -546,7 +638,7 @@ bool cmCPackPackageMakerGenerator::RunPackageMaker(const char *command,
   cmCPackLogger(cmCPackLog::LOG_VERBOSE, "Execute: " << command << std::endl);
   std::string output;
   int retVal = 1;
-  bool res = cmSystemTools::RunSingleCommand(command, &output, &retVal, 0, 
+  bool res = cmSystemTools::RunSingleCommand(command, &output, &retVal, 0,
                                              this->GeneratorVerbose, 0);
   cmCPackLogger(cmCPackLog::LOG_VERBOSE, "Done running package maker"
     << std::endl);
@@ -565,7 +657,7 @@ bool cmCPackPackageMakerGenerator::RunPackageMaker(const char *command,
   // sometimes the command finishes but the directory is not yet
   // created, so try 10 times to see if it shows up
   int tries = 10;
-  while(tries > 0 && 
+  while(tries > 0 &&
         !cmSystemTools::FileExists(packageFile))
     {
     cmSystemTools::Delay(500);
@@ -585,7 +677,7 @@ bool cmCPackPackageMakerGenerator::RunPackageMaker(const char *command,
 }
 
 //----------------------------------------------------------------------
-std::string 
+std::string
 cmCPackPackageMakerGenerator::GetPackageName(const cmCPackComponent& component)
 {
   if (component.ArchiveFile.empty())
@@ -617,7 +709,7 @@ GenerateComponentPackage(const char *packageFile,
   // The command that will be used to run PackageMaker
   cmOStringStream pkgCmd;
 
-  if (this->PackageCompatibilityVersion < 10.5 || 
+  if (this->PackageCompatibilityVersion < 10.5 ||
       this->PackageMakerVersion < 3.0)
     {
     // Create Description.plist and Info.plist files for normal Mac OS
@@ -633,10 +725,10 @@ GenerateComponentPackage(const char *packageFile,
         << "  <key>IFPkgDescriptionTitle</key>" << std::endl
         << "  <string>" << component.DisplayName << "</string>" << std::endl
         << "  <key>IFPkgDescriptionVersion</key>" << std::endl
-        << "  <string>" << this->GetOption("CPACK_PACKAGE_VERSION") 
+        << "  <string>" << this->GetOption("CPACK_PACKAGE_VERSION")
         << "</string>" << std::endl
         << "  <key>IFPkgDescriptionDescription</key>" << std::endl
-        << "  <string>" + this->EscapeForXML(component.Description) 
+        << "  <string>" + this->EscapeForXML(component.Description)
         << "</string>" << std::endl
         << "</dict>" << std::endl
         << "</plist>" << std::endl;
@@ -645,7 +737,7 @@ GenerateComponentPackage(const char *packageFile,
     // Create the Info.plist file for this component
     std::string moduleVersionSuffix = ".";
     moduleVersionSuffix += component.Name;
-    this->SetOption("CPACK_MODULE_VERSION_SUFFIX", 
+    this->SetOption("CPACK_MODULE_VERSION_SUFFIX",
                     moduleVersionSuffix.c_str());
     std::string infoFileName = component.Name;
     infoFileName += "-Info.plist";
@@ -657,9 +749,9 @@ GenerateComponentPackage(const char *packageFile,
     pkgCmd << "\"" << this->GetOption("CPACK_INSTALLER_PROGRAM")
            << "\" -build -p \"" << packageFile << "\""
            << " -f \"" << packageDir << "\""
-           << " -i \"" << this->GetOption("CPACK_TOPLEVEL_DIRECTORY") 
+           << " -i \"" << this->GetOption("CPACK_TOPLEVEL_DIRECTORY")
            << "/" << infoFileName << "\""
-           << " -d \"" << descriptionFile << "\""; 
+           << " -d \"" << descriptionFile << "\"";
     }
   else
     {
@@ -682,16 +774,16 @@ GenerateComponentPackage(const char *packageFile,
            << " --out \"" << packageFile << "\"";
     }
 
-  // Run PackageMaker  
+  // Run PackageMaker
   return RunPackageMaker(pkgCmd.str().c_str(), packageFile);
 }
 
 //----------------------------------------------------------------------
-void 
+void
 cmCPackPackageMakerGenerator::
 WriteDistributionFile(const char* metapackageFile)
 {
-  std::string distributionTemplate 
+  std::string distributionTemplate
     = this->FindTemplate("CPack.distribution.dist.in");
   if ( distributionTemplate.empty() )
     {
@@ -710,8 +802,8 @@ WriteDistributionFile(const char* metapackageFile)
 
   // Emit the outline for the groups
   std::map<std::string, cmCPackComponentGroup>::iterator groupIt;
-  for (groupIt = this->ComponentGroups.begin(); 
-       groupIt != this->ComponentGroups.end(); 
+  for (groupIt = this->ComponentGroups.begin();
+       groupIt != this->ComponentGroups.end();
        ++groupIt)
     {
     if (groupIt->second.ParentGroup == 0)
@@ -731,11 +823,16 @@ WriteDistributionFile(const char* metapackageFile)
                 << std::endl;
       }
     }
+  if(!this->PostFlightComponent.Name.empty())
+    {
+      choiceOut << "<line choice=\"" << PostFlightComponent.Name
+                << "Choice\"></line>" << std::endl;
+    }
   choiceOut << "</choices-outline>" << std::endl;
 
   // Create the actual choices
-  for (groupIt = this->ComponentGroups.begin(); 
-       groupIt != this->ComponentGroups.end(); 
+  for (groupIt = this->ComponentGroups.begin();
+       groupIt != this->ComponentGroups.end();
        ++groupIt)
     {
     CreateChoice(groupIt->second, choiceOut);
@@ -745,11 +842,17 @@ WriteDistributionFile(const char* metapackageFile)
     {
     CreateChoice(compIt->second, choiceOut);
     }
+
+  if(!this->PostFlightComponent.Name.empty())
+    {
+    CreateChoice(PostFlightComponent, choiceOut);
+    }
+
   this->SetOption("CPACK_PACKAGEMAKER_CHOICES", choiceOut.str().c_str());
 
   // Create the distribution.dist file in the metapackage to turn it
   // into a distribution package.
-  this->ConfigureFile(distributionTemplate.c_str(), 
+  this->ConfigureFile(distributionTemplate.c_str(),
                       distributionFile.c_str());
 }
 
@@ -777,13 +880,13 @@ CreateChoiceOutline(const cmCPackComponentGroup& group, cmOStringStream& out)
 }
 
 //----------------------------------------------------------------------
-void 
+void
 cmCPackPackageMakerGenerator::CreateChoice(const cmCPackComponentGroup& group,
                                            cmOStringStream& out)
 {
-  out << "<choice id=\"" << group.Name << "Choice\" " 
+  out << "<choice id=\"" << group.Name << "Choice\" "
       << "title=\"" << group.DisplayName << "\" "
-      << "start_selected=\"true\" " 
+      << "start_selected=\"true\" "
       << "start_enabled=\"true\" "
       << "start_visible=\"true\" ";
   if (!group.Description.empty())
@@ -795,21 +898,21 @@ cmCPackPackageMakerGenerator::CreateChoice(const cmCPackComponentGroup& group,
 }
 
 //----------------------------------------------------------------------
-void 
+void
 cmCPackPackageMakerGenerator::CreateChoice(const cmCPackComponent& component,
                                            cmOStringStream& out)
 {
   std::string packageId = "com.";
   packageId += this->GetOption("CPACK_PACKAGE_VENDOR");
-  packageId += '.'; 
+  packageId += '.';
   packageId += this->GetOption("CPACK_PACKAGE_NAME");
   packageId += '.';
   packageId += component.Name;
 
-  out << "<choice id=\"" << component.Name << "Choice\" " 
+  out << "<choice id=\"" << component.Name << "Choice\" "
       << "title=\"" << component.DisplayName << "\" "
-      << "start_selected=\"" 
-      << (component.IsDisabledByDefault && 
+      << "start_selected=\""
+      << (component.IsDisabledByDefault &&
           !component.IsRequired? "false" : "true")
       << "\" "
       << "start_enabled=\""
@@ -858,7 +961,7 @@ cmCPackPackageMakerGenerator::CreateChoice(const cmCPackComponent& component,
   std::string dirName = this->GetOption("CPACK_TEMPORARY_DIRECTORY");
   dirName += '/';
   dirName += component.Name;
-  unsigned long installedSize 
+  unsigned long installedSize
     = component.GetInstalledSizeInKbytes(dirName.c_str());
 
   out << "<pkg-ref id=\"" << packageId << "\" "
@@ -867,7 +970,7 @@ cmCPackPackageMakerGenerator::CreateChoice(const cmCPackComponent& component,
       << "auth=\"Admin\" onConclusion=\"None\">";
   if (component.IsDownloaded)
     {
-    out << this->GetOption("CPACK_DOWNLOAD_SITE") 
+    out << this->GetOption("CPACK_DOWNLOAD_SITE")
         << this->GetPackageName(component);
     }
   else
@@ -878,9 +981,9 @@ cmCPackPackageMakerGenerator::CreateChoice(const cmCPackComponent& component,
 }
 
 //----------------------------------------------------------------------
-void 
+void
 cmCPackPackageMakerGenerator::
-AddDependencyAttributes(const cmCPackComponent& component, 
+AddDependencyAttributes(const cmCPackComponent& component,
                         std::set<const cmCPackComponent *>& visited,
                         cmOStringStream& out)
 {
@@ -895,16 +998,16 @@ AddDependencyAttributes(const cmCPackComponent& component,
        dependIt != component.Dependencies.end();
        ++dependIt)
     {
-    out << " &amp;&amp; choices['" << 
+    out << " &amp;&amp; choices['" <<
       (*dependIt)->Name << "Choice'].selected";
     AddDependencyAttributes(**dependIt, visited, out);
     }
 }
 
 //----------------------------------------------------------------------
-void 
+void
 cmCPackPackageMakerGenerator::
-AddReverseDependencyAttributes(const cmCPackComponent& component, 
+AddReverseDependencyAttributes(const cmCPackComponent& component,
                                std::set<const cmCPackComponent *>& visited,
                                cmOStringStream& out)
 {
