@@ -13,9 +13,9 @@
 #include "cmCPackTarCompressGenerator.h"
 
 //----------------------------------------------------------------------
-cmCPackTarCompressGenerator::cmCPackTarCompressGenerator() 
-  :cmCPackArchiveGenerator(cmCPackArchiveGenerator::COMPRESS,
-                           cmCPackArchiveGenerator::TAR)
+cmCPackTarCompressGenerator::cmCPackTarCompressGenerator()
+  :cmCPackArchiveGenerator(cmArchiveWrite::CompressCompress,
+                           cmArchiveWrite::TypeTAR)
 {
 }
 
