@@ -1,19 +1,14 @@
-/*=========================================================================
+/*============================================================================
+  CMake - Cross Platform Makefile Generator
+  Copyright 2000-2009 Kitware, Inc., Insight Software Consortium
 
-  Program:   CMake - Cross-Platform Makefile Generator
-  Module:    $RCSfile: cmAddCustomCommandCommand.cxx,v $
-  Language:  C++
-  Date:      $Date: 2008-01-30 16:22:10 $
-  Version:   $Revision: 1.37 $
+  Distributed under the OSI-approved BSD License (the "License");
+  see accompanying file Copyright.txt for details.
 
-  Copyright (c) 2002 Kitware, Inc., Insight Consortium.  All rights reserved.
-  See Copyright.txt or http://www.cmake.org/HTML/Copyright.html for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
+  This software is distributed WITHOUT ANY WARRANTY; without even the
+  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+  See the License for more information.
+============================================================================*/
 #include "cmAddCustomCommandCommand.h"
 
 #include "cmTarget.h"
@@ -166,6 +161,7 @@ bool cmAddCustomCommandCommand
             filename += "/";
             }
           filename += copy;
+          cmSystemTools::ConvertToUnixSlashes(filename);
           break;
         case doing_source:
           // We do not want to convert the argument to SOURCE because
@@ -199,11 +195,13 @@ bool cmAddCustomCommandCommand
            {
            // An implicit dependency starting point is also an
            // explicit dependency.
-           depends.push_back(copy);
+           std::string dep = copy;
+           cmSystemTools::ConvertToUnixSlashes(dep);
+           depends.push_back(dep);
 
            // Add the implicit dependency language and file.
            cmCustomCommand::ImplicitDependsPair
-             entry(implicit_depends_lang, copy);
+             entry(implicit_depends_lang, dep);
            implicit_depends.push_back(entry);
 
            // Switch back to looking for a language.
@@ -217,7 +215,11 @@ bool cmAddCustomCommandCommand
            target = copy;
            break;
          case doing_depends:
-           depends.push_back(copy);
+           {
+           std::string dep = copy;
+           cmSystemTools::ConvertToUnixSlashes(dep);
+           depends.push_back(dep);
+           }
            break;
          case doing_outputs:
            outputs.push_back(filename);
@@ -290,6 +292,13 @@ bool cmAddCustomCommandCommand
     return false;
     }
 
+  // Convert working directory to a full path.
+  if(!working.empty())
+    {
+    const char* build_dir = this->Makefile->GetCurrentOutputDirectory();
+    working = cmSystemTools::CollapseFullPath(working.c_str(), build_dir);
+    }
+
   // Choose which mode of the command to use.
   bool escapeOldStyle = !verbatim;
   if(source.empty() && output.empty())
