@@ -19,7 +19,12 @@
 #include <cmsys/CPU.h>
 
 // Include the ELF format information system header.
-#include <elf.h>
+#if defined(__OpenBSD__)
+# include <stdint.h>
+# include <elf_abi.h>
+#else
+# include <elf.h>
+#endif
 #if defined(__sun)
 # include <sys/link.h> // For dynamic section information
 #endif
