@@ -1,19 +1,14 @@
-/*=========================================================================
+/*============================================================================
+  CMake - Cross Platform Makefile Generator
+  Copyright 2000-2009 Kitware, Inc., Insight Software Consortium
 
-  Program:   CMake - Cross-Platform Makefile Generator
-  Module:    $RCSfile: cmFLTKWrapUICommand.cxx,v $
-  Language:  C++
-  Date:      $Date: 2008-01-23 15:27:59 $
-  Version:   $Revision: 1.38 $
+  Distributed under the OSI-approved BSD License (the "License");
+  see accompanying file Copyright.txt for details.
 
-  Copyright (c) 2002 Kitware, Inc., Insight Consortium.  All rights reserved.
-  See Copyright.txt or http://www.cmake.org/HTML/Copyright.html for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
+  This software is distributed WITHOUT ANY WARRANTY; without even the
+  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+  See the License for more information.
+============================================================================*/
 #include "cmFLTKWrapUICommand.h"
 
 #include "cmSourceFile.h"
@@ -38,19 +33,23 @@ bool cmFLTKWrapUICommand
 
   std::vector<std::string> newArgs;
   this->Makefile->ExpandSourceListArguments(args,newArgs, 1);
-  
-  // get the list of GUI files from which .cxx and .h will be generated 
+
+  // get the list of GUI files from which .cxx and .h will be generated
   std::string outputDirectory = this->Makefile->GetCurrentOutputDirectory();
 
-  // Some of the generated files are *.h so the directory "GUI" 
+  {
+  // Some of the generated files are *.h so the directory "GUI"
   // where they are created have to be added to the include path
-  this->Makefile->AddIncludeDirectory( outputDirectory.c_str() );
+  std::vector<std::string> outputDirectories;
+  outputDirectories.push_back(outputDirectory);
+  this->Makefile->AddIncludeDirectories( outputDirectories );
+  }
 
-  for(std::vector<std::string>::iterator i = (newArgs.begin() + 1); 
+  for(std::vector<std::string>::iterator i = (newArgs.begin() + 1);
       i != newArgs.end(); i++)
     {
     cmSourceFile *curr = this->Makefile->GetSource(i->c_str());
-    // if we should use the source GUI 
+    // if we should use the source GUI
     // to generate .cxx and .h files
     if (!curr || !curr->GetPropertyAsBool("WRAP_EXCLUDE"))
       {
@@ -112,21 +111,33 @@ bool cmFLTKWrapUICommand
   std::string varName = this->Target;
   varName += "_FLTK_UI_SRCS";
   this->Makefile->AddDefinition(varName.c_str(), sourceListValue.c_str());
-  
+
   return true;
 }
 
-void cmFLTKWrapUICommand::FinalPass() 
+void cmFLTKWrapUICommand::FinalPass()
 {
   // people should add the srcs to the target themselves, but the old command
   // didn't support that, so check and see if they added the files in and if
   // they didn;t then print a warning and add then anyhow
-  std::vector<cmSourceFile*> const& srcs = 
-    this->Makefile->GetTargets()[this->Target].GetSourceFiles();
+  cmTarget* target = this->Makefile->FindTarget(this->Target.c_str());
+  if(!target)
+    {
+    std::string msg =
+      "FLTK_WRAP_UI was called with a target that was never created: ";
+    msg += this->Target;
+    msg +=".  The problem was found while processing the source directory: ";
+    msg += this->Makefile->GetStartDirectory();
+    msg += ".  This FLTK_WRAP_UI call will be ignored.";
+    cmSystemTools::Message(msg.c_str(),"Warning");
+    return;
+    }
+  std::vector<cmSourceFile*> const& srcs =
+    target->GetSourceFiles();
   bool found = false;
   for (unsigned int i = 0; i < srcs.size(); ++i)
     {
-    if (srcs[i]->GetFullPath() == 
+    if (srcs[i]->GetFullPath() ==
         this->GeneratedSourcesClasses[0]->GetFullPath())
       {
       found = true;
@@ -135,7 +146,7 @@ void cmFLTKWrapUICommand::FinalPass()
     }
   if (!found)
     {
-    std::string msg = 
+    std::string msg =
       "In CMake 2.2 the FLTK_WRAP_UI command sets a variable to the list of "
       "source files that should be added to your executable or library. It "
       "appears that you have not added these source files to your target. "
@@ -146,13 +157,13 @@ void cmFLTKWrapUICommand::FinalPass()
       "of sources to add to your target when you call ADD_LIBRARY or "
       "ADD_EXECUTABLE. For now CMake will add the sources to your target "
       "for you as was done in CMake 2.0 and earlier. In the future this may "
-      "become an error."; 
+      "become an error.";
     msg +="The problem was found while processing the source directory: ";
     msg += this->Makefile->GetStartDirectory();
     cmSystemTools::Message(msg.c_str(),"Warning");
     // first we add the rules for all the .fl to .h and .cxx files
     size_t lastHeadersClass = this->GeneratedSourcesClasses.size();
-    
+
     // Generate code for all the .fl files
     for(size_t classNum = 0; classNum < lastHeadersClass; classNum++)
       {
