@@ -10,11 +10,13 @@
   See the License for more information.
 ============================================================================*/
 #include "cmFindBase.h"
-  
+
 cmFindBase::cmFindBase()
 {
   this->AlreadyInCache = false;
   this->AlreadyInCacheWithoutMetaInfo = false;
+  this->NamesPerDir = false;
+  this->NamesPerDirAllowed = false;
 }
 
 //----------------------------------------------------------------------------
@@ -132,7 +134,7 @@ bool cmFindBase::ParseArguments(std::vector<std::string> const& argsIn)
   bool compatibility = this->Makefile->NeedBackwardsCompatibility(2,3);
 
   // copy argsIn into args so it can be modified,
-  // in the process extract the DOC "documentation" 
+  // in the process extract the DOC "documentation"
   size_t size = argsIn.size();
   std::vector<std::string> args;
   bool foundDoc = false;
@@ -178,7 +180,7 @@ bool cmFindBase::ParseArguments(std::vector<std::string> const& argsIn)
     this->AlreadyInCache = true;
     return true;
     }
-  this->AlreadyInCache = false; 
+  this->AlreadyInCache = false;
 
   // Find the current root path mode.
   this->SelectDefaultRootPathMode();
@@ -213,6 +215,19 @@ bool cmFindBase::ParseArguments(std::vector<std::string> const& argsIn)
       compatibility = false;
       newStyle = true;
       }
+    else if (args[j] == "NAMES_PER_DIR")
+      {
+      doing = DoingNone;
+      if(this->NamesPerDirAllowed)
+        {
+        this->NamesPerDir = true;
+        }
+      else
+        {
+        this->SetError("does not support NAMES_PER_DIR");
+        return false;
+        }
+      }
     else if (args[j] == "NO_SYSTEM_PATH")
       {
       doing = DoingNone;
@@ -264,17 +279,17 @@ bool cmFindBase::ParseArguments(std::vector<std::string> const& argsIn)
       }
     else if(this->Names.size() == 1)
       {
-      this->VariableDocumentation += "the " 
+      this->VariableDocumentation += "the "
         + this->Names[0] + " library be found";
       }
     else
-      { 
+      {
       this->VariableDocumentation += "one of the " + this->Names[0];
       for (unsigned int j = 1; j < this->Names.size() - 1; ++j)
         {
         this->VariableDocumentation += ", " + this->Names[j];
         }
-      this->VariableDocumentation += " or " 
+      this->VariableDocumentation += " or "
         + this->Names[this->Names.size() - 1] + " libraries be found";
       }
     }
@@ -345,13 +360,13 @@ void cmFindBase::AddPrefixPaths(std::vector<std::string> const& in_paths,
       {
       dir += "/";
       }
-    if(subdir == "lib")
+    if(subdir == "include" || subdir == "lib")
       {
       const char* arch =
         this->Makefile->GetDefinition("CMAKE_LIBRARY_ARCHITECTURE");
       if(arch && *arch)
         {
-        this->AddPathInternal(dir+"lib/"+arch, pathType);
+        this->AddPathInternal(dir+subdir+"/"+arch, pathType);
         }
       }
     std::string add = dir + subdir;
@@ -504,7 +519,7 @@ void cmFindBase::AddPathSuffixes()
     cmSystemTools::ConvertToUnixSlashes(*i);
     // copy each finalPath combined with SearchPathSuffixes
     // to the SearchPaths ivar
-    for(std::vector<std::string>::iterator j = 
+    for(std::vector<std::string>::iterator j =
           this->SearchPathSuffixes.begin();
         j != this->SearchPathSuffixes.end(); ++j)
       {
@@ -517,7 +532,7 @@ void cmFindBase::AddPathSuffixes()
         p += std::string("/");
         }
       p +=  *j;
-      // add to all paths because the search path may be modified 
+      // add to all paths because the search path may be modified
       // later with lib being replaced for lib64 which may exist
       paths.push_back(p);
       }
@@ -535,13 +550,13 @@ void cmFindBase::PrintFindStuff()
   std::cerr << "SearchAppBundleOnly: " << this->SearchAppBundleOnly << "\n";
   std::cerr << "SearchAppBundleFirst: " << this->SearchAppBundleFirst << "\n";
   std::cerr << "VariableName " << this->VariableName << "\n";
-  std::cerr << "VariableDocumentation " 
+  std::cerr << "VariableDocumentation "
             << this->VariableDocumentation << "\n";
   std::cerr << "NoDefaultPath " << this->NoDefaultPath << "\n";
-  std::cerr << "NoCMakeEnvironmentPath " 
+  std::cerr << "NoCMakeEnvironmentPath "
             << this->NoCMakeEnvironmentPath << "\n";
   std::cerr << "NoCMakePath " << this->NoCMakePath << "\n";
-  std::cerr << "NoSystemEnvironmentPath " 
+  std::cerr << "NoSystemEnvironmentPath "
             << this->NoSystemEnvironmentPath << "\n";
   std::cerr << "NoCMakeSystemPath " << this->NoCMakeSystemPath << "\n";
   std::cerr << "EnvironmentPath " << this->EnvironmentPath << "\n";
