@@ -29,7 +29,7 @@ public:
   /**
    * This is a virtual constructor for the command.
    */
-  virtual cmCommand* Clone() 
+  virtual cmCommand* Clone()
     {
     return new cmFindLibraryCommand;
     }
@@ -59,15 +59,22 @@ public:
     return "Find a library.";
     }
   cmTypeMacro(cmFindLibraryCommand, cmFindBase);
-  
+
 protected:
   void AddArchitecturePaths(const char* suffix);
-  void AddLib64Paths();
+  void AddArchitecturePath(std::string const& dir,
+                           std::string::size_type start_pos,
+                           const char* suffix,
+                           bool fresh = true);
   std::string FindLibrary();
   virtual void GenerateDocumentation();
 private:
   std::string FindNormalLibrary();
+  std::string FindNormalLibraryNamesPerDir();
+  std::string FindNormalLibraryDirsPerName();
   std::string FindFrameworkLibrary();
+  std::string FindFrameworkLibraryNamesPerDir();
+  std::string FindFrameworkLibraryDirsPerName();
 };
 
 
