@@ -1,24 +1,20 @@
-/*=========================================================================
+/*============================================================================
+  CMake - Cross Platform Makefile Generator
+  Copyright 2000-2009 Kitware, Inc., Insight Software Consortium
 
-  Program:   CMake - Cross-Platform Makefile Generator
-  Module:    $RCSfile: cmInstallTargetGenerator.h,v $
-  Language:  C++
-  Date:      $Date: 2008-07-13 21:55:24 $
-  Version:   $Revision: 1.24.2.2 $
+  Distributed under the OSI-approved BSD License (the "License");
+  see accompanying file Copyright.txt for details.
 
-  Copyright (c) 2002 Kitware, Inc., Insight Consortium.  All rights reserved.
-  See Copyright.txt or http://www.cmake.org/HTML/Copyright.html for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
+  This software is distributed WITHOUT ANY WARRANTY; without even the
+  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+  See the License for more information.
+============================================================================*/
 #ifndef cmInstallTargetGenerator_h
 #define cmInstallTargetGenerator_h
 
 #include "cmInstallGenerator.h"
 #include "cmTarget.h"
+#include "cmGeneratorTarget.h"
 
 /** \class cmInstallTargetGenerator
  * \brief Generate target installation rules.
@@ -29,7 +25,7 @@ public:
   cmInstallTargetGenerator(
     cmTarget& t, const char* dest, bool implib,
     const char* file_permissions = "",
-    std::vector<std::string> const& configurations 
+    std::vector<std::string> const& configurations
     = std::vector<std::string>(),
     const char* component = "Unspecified",
     bool optional = false
@@ -64,16 +60,24 @@ public:
   bool IsImportLibrary() const { return this->ImportLibrary; }
 
 protected:
-  typedef cmInstallGeneratorIndent Indent;
   virtual void GenerateScript(std::ostream& os);
-  void GenerateScriptForConfig(std::ostream& os,
-                               const char* fromDir,
-                               const char* config,
-                               Indent const& indent);
-  void GenerateScriptForConfigDir(std::ostream& os,
-                                  const char* fromDirConfig,
-                                  const char* config,
-                                  Indent const& indent);
+  virtual void GenerateScriptForConfig(std::ostream& os,
+                                       const char* config,
+                                       Indent const& indent);
+  typedef void (cmInstallTargetGenerator::*TweakMethod)(
+    std::ostream&, Indent const&, const char*, std::string const&
+    );
+  void AddTweak(std::ostream& os, Indent const& indent,
+                const char* config, std::string const& file,
+                TweakMethod tweak);
+  void AddTweak(std::ostream& os, Indent const& indent,
+                const char* config, std::vector<std::string> const& files,
+                TweakMethod tweak);
+  std::string GetDestDirPath(std::string const& file);
+  void PreReplacementTweaks(std::ostream& os, Indent const& indent,
+                            const char* config, std::string const& file);
+  void PostReplacementTweaks(std::ostream& os, Indent const& indent,
+                             const char* config, std::string const& file);
   void AddInstallNamePatchRule(std::ostream& os, Indent const& indent,
                                const char* config,
                                const std::string& toDestDirPath);
@@ -83,12 +87,10 @@ protected:
   void AddRPathCheckRule(std::ostream& os, Indent const& indent,
                          const char* config,
                          std::string const& toDestDirPath);
-  
+
   void AddStripRule(std::ostream& os, Indent const& indent,
-                    cmTarget::TargetType type,
                     const std::string& toDestDirPath);
   void AddRanlibRule(std::ostream& os, Indent const& indent,
-                     cmTarget::TargetType type,
                      const std::string& toDestDirPath);
 
   cmTarget* Target;
@@ -96,6 +98,7 @@ protected:
   std::string FilePermissions;
   bool Optional;
   NamelinkModeType NamelinkMode;
+  cmGeneratorTarget* GeneratorTarget;
 };
 
 #endif
