@@ -19,7 +19,7 @@
  *
  * cmInstallTargetsCommand specifies the relative path where a list of
  * targets should be installed. The targets can be executables or
- * libraries.  
+ * libraries.
  */
 class cmInstallTargetsCommand : public cmCommand
 {
@@ -27,7 +27,7 @@ public:
   /**
    * This is a virtual constructor for the command.
    */
-  virtual cmCommand* Clone() 
+  virtual cmCommand* Clone()
     {
     return new cmInstallTargetsCommand;
     }
@@ -42,20 +42,20 @@ public:
   /**
    * The name of the command as specified in CMakeList.txt.
    */
-  virtual const char* GetName() { return "install_targets";}
+  virtual const char* GetName() const { return "install_targets";}
 
   /**
    * Succinct documentation.
    */
-  virtual const char* GetTerseDocumentation() 
+  virtual const char* GetTerseDocumentation() const
     {
     return "Deprecated. Use the install(TARGETS )  command instead.";
     }
-  
+
   /**
    * More documentation.
    */
-  virtual const char* GetFullDocumentation()
+  virtual const char* GetFullDocumentation() const
     {
     return
       "This command has been superceded by the install command.  It "
@@ -67,9 +67,9 @@ public:
       "is specified, then on systems with special runtime files "
       "(Windows DLL), the files will be copied to that directory.";
     }
-  
+
   /** This command is kept for compatibility with older CMake versions. */
-  virtual bool IsDiscouraged()
+  virtual bool IsDiscouraged() const
     {
     return true;
     }
