@@ -21,7 +21,7 @@ public:
   /**
    * This is a virtual constructor for the command.
    */
-  virtual cmCommand* Clone() 
+  virtual cmCommand* Clone()
     {
     return new cmMathCommand;
     }
@@ -50,7 +50,7 @@ public:
     {
     return "Mathematical expressions.";
     }
-  
+
   /**
    * More documentation.
    */
@@ -58,16 +58,16 @@ public:
     {
     return
       "  math(EXPR <output variable> <math expression>)\n"
-      "EXPR evaluates mathematical expression and return result in the "
+      "EXPR evaluates mathematical expression and returns result in the "
       "output variable. Example mathematical expression is "
       "'5 * ( 10 + 13 )'.  Supported operators are "
       "+ - * / % | & ^ ~ << >> * / %.  They have the same meaning "
-      " as they do in c code.";
+      " as they do in C code.";
     }
-  
+
   cmTypeMacro(cmMathCommand, cmCommand);
 protected:
- 
+
   bool HandleExprCommand(std::vector<std::string> const& args);
 };
 
