@@ -40,16 +40,21 @@ public:
 
   virtual void Generate() = 0;
 
-  std::string GetTargetPDB() const;
   std::string GetTargetName() const;
 
 protected:
+
+  bool SetMsvcTargetPdbVariable(cmNinjaVars&) const;
+
   cmGeneratedFileStream& GetBuildFileStream() const;
   cmGeneratedFileStream& GetRulesFileStream() const;
 
   cmTarget* GetTarget() const
   { return this->Target; }
 
+  cmGeneratorTarget* GetGeneratorTarget() const
+  { return this->GeneratorTarget; }
+
   cmLocalNinjaGenerator* GetLocalGenerator() const
   { return this->LocalGenerator; }
 
@@ -112,8 +117,8 @@ protected:
   // Helper to add flag for windows .def file.
   void AddModuleDefinitionFlag(std::string& flags);
 
-  void EnsureDirectoryExists(const std::string& dir);
-  void EnsureParentDirectoryExists(const std::string& path);
+  void EnsureDirectoryExists(const std::string& dir) const;
+  void EnsureParentDirectoryExists(const std::string& path) const;
 
   // write rules for Mac OS X Application Bundle content.
   struct MacOSXContentGeneratorType :
