@@ -11,37 +11,6 @@
 ============================================================================*/
 #include "cmSourceGroupCommand.h"
 
-inline std::vector<std::string> tokenize(const std::string& str,
-                                         const std::string& sep)
-{
-  std::vector<std::string> tokens;
-  std::string::size_type tokend = 0;
-
-  do
-    {
-    std::string::size_type tokstart=str.find_first_not_of(sep, tokend);
-    if (tokstart==std::string::npos) 
-      {
-      break;    // no more tokens
-      }
-    tokend=str.find_first_of(sep,tokstart);
-    if (tokend==std::string::npos)
-      {
-      tokens.push_back(str.substr(tokstart));
-      }
-    else
-      {
-      tokens.push_back(str.substr(tokstart,tokend-tokstart));
-      }
-    } while (tokend!=std::string::npos);
-
-  if (tokens.empty())
-    {
-    tokens.push_back("");
-    }
-  return tokens;
-}
-
 // cmSourceGroupCommand
 bool cmSourceGroupCommand
 ::InitialPass(std::vector<std::string> const& args, cmExecutionStatus &)
@@ -50,7 +19,7 @@ bool cmSourceGroupCommand
     {
     this->SetError("called with incorrect number of arguments");
     return false;
-    }  
+    }
 
   std::string delimiter = "\\";
   if(this->Makefile->GetDefinition("SOURCE_GROUP_DELIMITER"))
@@ -58,8 +27,9 @@ bool cmSourceGroupCommand
     delimiter = this->Makefile->GetDefinition("SOURCE_GROUP_DELIMITER");
     }
 
-  std::vector<std::string> folders = tokenize(args[0], delimiter);
- 
+  std::vector<std::string> folders =
+    cmSystemTools::tokenize(args[0], delimiter);
+
   cmSourceGroup* sg = 0;
   sg = this->Makefile->GetSourceGroup(folders);
   if(!sg)
@@ -80,7 +50,7 @@ bool cmSourceGroupCommand
     sg->SetGroupRegex(args[1].c_str());
     return true;
     }
-  
+
   // Process arguments.
   bool doingFiles = false;
   for(unsigned int i=1; i < args.size(); ++i)
@@ -127,6 +97,6 @@ bool cmSourceGroupCommand
       return false;
       }
     }
-  
+
   return true;
 }
