@@ -1,19 +1,14 @@
-/*=========================================================================
+/*============================================================================
+  CMake - Cross Platform Makefile Generator
+  Copyright 2000-2009 Kitware, Inc., Insight Software Consortium
 
-  Program:   CMake - Cross-Platform Makefile Generator
-  Module:    $RCSfile: cmVariableRequiresCommand.h,v $
-  Language:  C++
-  Date:      $Date: 2005/11/23 17:33:39 $
-  Version:   $Revision: 1.9.2.1 $
+  Distributed under the OSI-approved BSD License (the "License");
+  see accompanying file Copyright.txt for details.
 
-  Copyright (c) 2002 Kitware, Inc., Insight Consortium.  All rights reserved.
-  See Copyright.txt or http://www.cmake.org/HTML/Copyright.html for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
+  This software is distributed WITHOUT ANY WARRANTY; without even the
+  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+  See the License for more information.
+============================================================================*/
 #ifndef cmVariableRequiresCommand_h
 #define cmVariableRequiresCommand_h
 
@@ -29,7 +24,7 @@ public:
   /**
    * This is a virtual constructor for the command.
    */
-  virtual cmCommand* Clone() 
+  virtual cmCommand* Clone()
     {
     return new cmVariableRequiresCommand;
     }
@@ -38,44 +33,49 @@ public:
    * This is called when the command is first encountered in
    * the CMakeLists.txt file.
    */
-  virtual bool InitialPass(std::vector<std::string> const& args);
-  
+  virtual bool InitialPass(std::vector<std::string> const& args,
+                           cmExecutionStatus &status);
+
   /**
    * The name of the command as specified in CMakeList.txt.
    */
-  virtual const char* GetName() { return "VARIABLE_REQUIRES";}
+  virtual const char* GetName() const { return "variable_requires";}
 
   /**
    * Succinct documentation.
    */
-  virtual const char* GetTerseDocumentation() 
+  virtual const char* GetTerseDocumentation() const
     {
-    return "Assert satisfaction of an option's required variables.";
+    return "Deprecated. Use the if() command instead.";
     }
-  
+
   /**
    * More documentation.
    */
-  virtual const char* GetFullDocumentation()
+  virtual const char* GetFullDocumentation() const
     {
     return
-      "  VARIABLE_REQUIRES(TEST_VARIABLE RESULT_VARIABLE\n"
+      "Assert satisfaction of an option's required variables.\n"
+      "  variable_requires(TEST_VARIABLE RESULT_VARIABLE\n"
       "                    REQUIRED_VARIABLE1\n"
       "                    REQUIRED_VARIABLE2 ...)\n"
       "The first argument (TEST_VARIABLE) is the name of the variable to be "
       "tested, if that variable is false nothing else is done. If "
       "TEST_VARIABLE is true, then "
       "the next argument (RESULT_VARIABLE) is a variable that is set to true "
-      "if all the required variables are set. " 
+      "if all the required variables are set. "
       "The rest of the arguments are variables that must be true or not "
       "set to NOTFOUND to avoid an error.  If any are not true, an error "
       "is reported.";
     }
-  
+
+  /** This command is kept for compatibility with older CMake versions. */
+  virtual bool IsDiscouraged() const
+    {
+    return true;
+    }
+
   cmTypeMacro(cmVariableRequiresCommand, cmCommand);
-private:
-  std::string m_ErrorMessage;
-  bool m_RequirementsMet;
 };
 
 
