@@ -47,9 +47,10 @@ public:
   void SetVerboseMakefile(bool verbose);
 
   // Check for specific options.
-  bool UsingUnicode();
+  bool UsingUnicode() const;
+  bool UsingSBCS() const;
 
-  bool IsDebug();
+  bool IsDebug() const;
   // Write options to output.
   void OutputPreprocessorDefinitions(std::ostream& fout,
                                      const char* prefix,
