@@ -1,19 +1,14 @@
-/*=========================================================================
+/*============================================================================
+  CMake - Cross Platform Makefile Generator
+  Copyright 2000-2009 Kitware, Inc., Insight Software Consortium
 
-  Program:   CMake - Cross-Platform Makefile Generator
-  Module:    $RCSfile: cmWin32ProcessExecution.h,v $
-  Language:  C++
-  Date:      $Date: 2006-05-12 18:12:13 $
-  Version:   $Revision: 1.13 $
+  Distributed under the OSI-approved BSD License (the "License");
+  see accompanying file Copyright.txt for details.
 
-  Copyright (c) 2002 Kitware, Inc., Insight Consortium.  All rights reserved.
-  See Copyright.txt or http://www.cmake.org/HTML/Copyright.html for details.
-
-     This software is distributed WITHOUT ANY WARRANTY; without even 
-     the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
-     PURPOSE.  See the above copyright notices for more information.
-
-=========================================================================*/
+  This software is distributed WITHOUT ANY WARRANTY; without even the
+  implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+  See the License for more information.
+============================================================================*/
 #ifndef cmWin32ProcessExecution_h
 #define cmWin32ProcessExecution_h
 
@@ -52,12 +47,12 @@ public:
   ~cmWin32ProcessExecution();
   ///! If true windows will be created hidden.
   void SetHideWindows(bool v) { this->HideWindows = v;  }
-  
+
   /**
    * Initialize the process execution datastructure. Do not call while
    * running the process.
    */
-  void Initialize() 
+  void Initialize()
     {
     this->ProcessHandle = 0;
     this->ExitValue    = -1;
@@ -70,11 +65,11 @@ public:
     this->pStdOut =  -1;
     this->pStdErr =  -1;
     }
-  
+
   /**
    * Start the process in the directory path. Make sure that the
    * executable is either in the path or specify the full path. The
-   * argument verbose specifies wether or not to display output while
+   * argument verbose specifies whether or not to display output while
    * it is being generated.
    */
   bool StartProcess(const char*, const char* path, bool verbose);
@@ -134,10 +129,10 @@ public:
    * process. Every time there is something availabe for reading, we
    * will display it in our app. Consequently, we check for input in
    * our app and send it off to the write end of the stdin pipe.
-   */ 
-  static bool BorlandRunCommand(const char* command, 
-                                const char* dir, 
-                                std::string& output, int& retVal, 
+   */
+  static bool BorlandRunCommand(const char* command,
+                                const char* dir,
+                                std::string& output, int& retVal,
                                 bool verbose,
                                 int timeout, bool hideWindows);
 
@@ -156,8 +151,8 @@ private:
   HANDLE hChildStdinWrDup;
   HANDLE hChildStdoutRdDup;
   HANDLE hChildStderrRdDup;
-  
-  
+
+
   int pStdIn;
   int pStdOut;
   int pStdErr;
